##  Activating the Extension
Admins can activate the application total cost of ownership extension in the administration area. Follow these steps:
  1. In the administration area, navigate to Optional Features & Early Access.
  2. In the Use Cases Extensions section, select Application Total Cost of Ownership (TCO).
  3. Click Activate to see the overview of all changes.
  4. Confirm the checkbox to acknowledge the changes and choose Activate Extension.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof51318b38e124e2eab00678f7f95504d_HiRes.png)
